pub struct CopyMode { /* private fields */ }Expand description
Manages copy mode state and terminal mouse capture.
Implementations
Sourceimpl CopyMode
impl CopyMode
Sourcepub fn toggle<W: Write>(&mut self, writer: &mut W) -> Result<()>
pub fn toggle<W: Write>(&mut self, writer: &mut W) -> Result<()>
Toggle copy mode on/off. Manages mouse capture accordingly.
Sourcepub fn activate<W: Write>(&mut self, writer: &mut W) -> Result<()>
pub fn activate<W: Write>(&mut self, writer: &mut W) -> Result<()>
Enter copy mode: disable mouse capture.
Sourcepub fn deactivate<W: Write>(&mut self, writer: &mut W) -> Result<()>
pub fn deactivate<W: Write>(&mut self, writer: &mut W) -> Result<()>
Exit copy mode: re-enable mouse capture if it was previously enabled.
Sourcepub fn status_indicator(&self) -> Option<Span<'static>>
pub fn status_indicator(&self) -> Option<Span<'static>>
Build a status indicator span for the key hints bar.
Sourcepub fn strip_borders(&self) -> bool
pub fn strip_borders(&self) -> bool
Whether panel borders should be stripped in copy mode.
Build a copy mode banner line for display at the top of the screen.