pub struct HeadlessRenderer { /* private fields */ }Expand description
A renderer that writes structured log lines to stderr.
Used when neither stream nor dashboard mode can initialize (no TTY, too small terminal, etc.).
Implementations
Sourceimpl HeadlessRenderer
impl HeadlessRenderer
pub fn new() -> Self
Sourcepub fn run(self, rx: UnboundedReceiver<StreamEvent>)
pub fn run(self, rx: UnboundedReceiver<StreamEvent>)
Consume events from the channel until it closes, writing structured output to stderr.