Module error

Module error 

Error types for yarli-git.

Covers worktree lifecycle, merge orchestration, submodule policy, recovery, and forbidden-operation errors (Sections 12.1–12.12).

Enums

ForbiddenOp
Forbidden git operations (Section 12.12, default-deny).
GitError
Top-level error type for all git-plane operations.
InterruptedOp
Interrupted git operations that can be detected on recovery (Section 12.10).
RecoveryAction
Recovery policy for interrupted operations (Section 12.10).